audformat.errors
================

.. automodule:: audformat.errors


BadIdError
----------

.. autoclass:: audformat.errors.BadIdError
    :members:

BadTypeError
------------

.. autoclass:: audformat.errors.BadTypeError
    :members:

BadValueError
-------------

.. autoclass:: audformat.errors.BadValueError
    :members:
